.. _utilipy-utils-pickle:

*******************************
Pickle (`utilipy.utils.pickle`)
*******************************

.. currentmodule:: utilipy.utils.pickle


Reference/API
=============

.. automodapi:: utilipy.utils.pickle
